@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import ast
-import atexit
 import builtins
 import collections
 import functools
@@ -284,9 +283,6 @@ def purge():
     _count = defaultdict(lambda: defaultdict(int))
 
 
-atexit.register(purge)
-
-
 def export() -> Config:
     """Export the global configuration.
 
